@@ -71,6 +71,13 @@ class PubMedArticle(MetaPubObject):
     def first_page(self):
         try:
             return self.pages.partition('-')[0]
+        except AttributeError:
+            return self.pages
+
+    @property
+    def last_page(self):
+        try:
+            return self.pages.partition('-')[1]
         except AttributeError:
             return None
 
